# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/cluster_assignment.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/cluster_assignment.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\'flyteidl/admin/cluster_assignment.proto\x12\x0e\x66lyteidl.admin\"?\n\x11\x43lusterAssignment\x12*\n\x08\x61\x66\x66inity\x18\x01 \x01(\x0b\x32\x18.flyteidl.admin.Affinity\"7\n\x08\x41\x66\x66inity\x12+\n\tselectors\x18\x01 \x03(\x0b\x32\x18.flyteidl.admin.Selector\"\xa3\x01\n\x08Selector\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x03(\t\x12\x33\n\x08operator\x18\x03 \x01(\x0e\x32!.flyteidl.admin.Selector.Operator\"F\n\x08Operator\x12\n\n\x06\x45QUALS\x10\x00\x12\x0e\n\nNOT_EQUALS\x10\x01\x12\x06\n\x02IN\x10\x02\x12\n\n\x06NOT_IN\x10\x03\x12\n\n\x06\x45XISTS\x10\x04\x42\x37Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
)



_SELECTOR_OPERATOR = _descriptor.EnumDescriptor(
  name='Operator',
  full_name='flyteidl.admin.Selector.Operator',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUALS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUALS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_IN', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXISTS', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=275,
  serialized_end=345,
)
_sym_db.RegisterEnumDescriptor(_SELECTOR_OPERATOR)


_CLUSTERASSIGNMENT = _descriptor.Descriptor(
  name='ClusterAssignment',
  full_name='flyteidl.admin.ClusterAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='affinity', full_name='flyteidl.admin.ClusterAssignment.affinity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=122,
)


_AFFINITY = _descriptor.Descriptor(
  name='Affinity',
  full_name='flyteidl.admin.Affinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selectors', full_name='flyteidl.admin.Affinity.selectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=179,
)


_SELECTOR = _descriptor.Descriptor(
  name='Selector',
  full_name='flyteidl.admin.Selector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.admin.Selector.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.admin.Selector.value', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='flyteidl.admin.Selector.operator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SELECTOR_OPERATOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=345,
)

_CLUSTERASSIGNMENT.fields_by_name['affinity'].message_type = _AFFINITY
_AFFINITY.fields_by_name['selectors'].message_type = _SELECTOR
_SELECTOR.fields_by_name['operator'].enum_type = _SELECTOR_OPERATOR
_SELECTOR_OPERATOR.containing_type = _SELECTOR
DESCRIPTOR.message_types_by_name['ClusterAssignment'] = _CLUSTERASSIGNMENT
DESCRIPTOR.message_types_by_name['Affinity'] = _AFFINITY
DESCRIPTOR.message_types_by_name['Selector'] = _SELECTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClusterAssignment = _reflection.GeneratedProtocolMessageType('ClusterAssignment', (_message.Message,), dict(
  DESCRIPTOR = _CLUSTERASSIGNMENT,
  __module__ = 'flyteidl.admin.cluster_assignment_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ClusterAssignment)
  ))
_sym_db.RegisterMessage(ClusterAssignment)

Affinity = _reflection.GeneratedProtocolMessageType('Affinity', (_message.Message,), dict(
  DESCRIPTOR = _AFFINITY,
  __module__ = 'flyteidl.admin.cluster_assignment_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Affinity)
  ))
_sym_db.RegisterMessage(Affinity)

Selector = _reflection.GeneratedProtocolMessageType('Selector', (_message.Message,), dict(
  DESCRIPTOR = _SELECTOR,
  __module__ = 'flyteidl.admin.cluster_assignment_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Selector)
  ))
_sym_db.RegisterMessage(Selector)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/identity.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/service/identity.proto',
  package='flyteidl.service',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/service'),
  serialized_pb=_b('\n\x1f\x66lyteidl/service/identity.proto\x12\x10\x66lyteidl.service\x1a\x1cgoogle/api/annotations.proto\x1a,protoc-gen-swagger/options/annotations.proto\"\x11\n\x0fUserInfoRequest\"\x96\x01\n\x10UserInfoResponse\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12preferred_username\x18\x03 \x01(\t\x12\x12\n\ngiven_name\x18\x04 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12\x0f\n\x07picture\x18\x07 \x01(\t2\x9d\x01\n\x0fIdentityService\x12\x89\x01\n\x08UserInfo\x12!.flyteidl.service.UserInfoRequest\x1a\".flyteidl.service.UserInfoResponse\"6\x82\xd3\xe4\x93\x02\x05\x12\x03/me\x92\x41(\x1a&Retrieves authenticated identity info.B9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/serviceb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_USERINFOREQUEST = _descriptor.Descriptor(
  name='UserInfoRequest',
  full_name='flyteidl.service.UserInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=146,
)


_USERINFORESPONSE = _descriptor.Descriptor(
  name='UserInfoResponse',
  full_name='flyteidl.service.UserInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='flyteidl.service.UserInfoResponse.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.service.UserInfoResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_username', full_name='flyteidl.service.UserInfoResponse.preferred_username', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='given_name', full_name='flyteidl.service.UserInfoResponse.given_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='family_name', full_name='flyteidl.service.UserInfoResponse.family_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='flyteidl.service.UserInfoResponse.email', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='picture', full_name='flyteidl.service.UserInfoResponse.picture', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=299,
)

DESCRIPTOR.message_types_by_name['UserInfoRequest'] = _USERINFOREQUEST
DESCRIPTOR.message_types_by_name['UserInfoResponse'] = _USERINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserInfoRequest = _reflection.GeneratedProtocolMessageType('UserInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _USERINFOREQUEST,
  __module__ = 'flyteidl.service.identity_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.UserInfoRequest)
  ))
_sym_db.RegisterMessage(UserInfoRequest)

UserInfoResponse = _reflection.GeneratedProtocolMessageType('UserInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERINFORESPONSE,
  __module__ = 'flyteidl.service.identity_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.UserInfoResponse)
  ))
_sym_db.RegisterMessage(UserInfoResponse)


DESCRIPTOR._options = None

_IDENTITYSERVICE = _descriptor.ServiceDescriptor(
  name='IdentityService',
  full_name='flyteidl.service.IdentityService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=302,
  serialized_end=459,
  methods=[
  _descriptor.MethodDescriptor(
    name='UserInfo',
    full_name='flyteidl.service.IdentityService.UserInfo',
    index=0,
    containing_service=None,
    input_type=_USERINFOREQUEST,
    output_type=_USERINFORESPONSE,
    serialized_options=_b('\202\323\344\223\002\005\022\003/me\222A(\032&Retrieves authenticated identity info.'),
  ),
])
_sym_db.RegisterServiceDescriptor(_IDENTITYSERVICE)

DESCRIPTOR.services_by_name['IdentityService'] = _IDENTITYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/array_job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/array_job.proto',
  package='flyteidl.plugins',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n flyteidl/plugins/array_job.proto\x12\x10\x66lyteidl.plugins\"w\n\x08\x41rrayJob\x12\x13\n\x0bparallelism\x18\x01 \x01(\x03\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\x17\n\rmin_successes\x18\x03 \x01(\x03H\x00\x12\x1b\n\x11min_success_ratio\x18\x04 \x01(\x02H\x00\x42\x12\n\x10success_criteriaB9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
)




_ARRAYJOB = _descriptor.Descriptor(
  name='ArrayJob',
  full_name='flyteidl.plugins.ArrayJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parallelism', full_name='flyteidl.plugins.ArrayJob.parallelism', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='flyteidl.plugins.ArrayJob.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_successes', full_name='flyteidl.plugins.ArrayJob.min_successes', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_success_ratio', full_name='flyteidl.plugins.ArrayJob.min_success_ratio', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='success_criteria', full_name='flyteidl.plugins.ArrayJob.success_criteria',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=54,
  serialized_end=173,
)

_ARRAYJOB.oneofs_by_name['success_criteria'].fields.append(
  _ARRAYJOB.fields_by_name['min_successes'])
_ARRAYJOB.fields_by_name['min_successes'].containing_oneof = _ARRAYJOB.oneofs_by_name['success_criteria']
_ARRAYJOB.oneofs_by_name['success_criteria'].fields.append(
  _ARRAYJOB.fields_by_name['min_success_ratio'])
_ARRAYJOB.fields_by_name['min_success_ratio'].containing_oneof = _ARRAYJOB.oneofs_by_name['success_criteria']
DESCRIPTOR.message_types_by_name['ArrayJob'] = _ARRAYJOB
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ArrayJob = _reflection.GeneratedProtocolMessageType('ArrayJob', (_message.Message,), dict(
  DESCRIPTOR = _ARRAYJOB,
  __module__ = 'flyteidl.plugins.array_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.ArrayJob)
  ))
_sym_db.RegisterMessage(ArrayJob)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/catalog.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/core/catalog.proto',
  package='flyteidl.core',
  syntax='proto3',
  serialized_options=_b('Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/core'),
  serialized_pb=_b('\n\x1b\x66lyteidl/core/catalog.proto\x12\rflyteidl.core\x1a\x1e\x66lyteidl/core/identifier.proto\"7\n\x12\x43\x61talogArtifactTag\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd6\x01\n\x0f\x43\x61talogMetadata\x12-\n\ndataset_id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12\x37\n\x0c\x61rtifact_tag\x18\x02 \x01(\x0b\x32!.flyteidl.core.CatalogArtifactTag\x12G\n\x15source_task_execution\x18\x03 \x01(\x0b\x32&.flyteidl.core.TaskExecutionIdentifierH\x00\x42\x12\n\x10source_execution\"\x9e\x01\n\x12\x43\x61talogReservation\"\x87\x01\n\x06Status\x12\x18\n\x14RESERVATION_DISABLED\x10\x00\x12\x18\n\x14RESERVATION_ACQUIRED\x10\x01\x12\x16\n\x12RESERVATION_EXISTS\x10\x02\x12\x18\n\x14RESERVATION_RELEASED\x10\x03\x12\x17\n\x13RESERVATION_FAILURE\x10\x04*\x8d\x01\n\x12\x43\x61talogCacheStatus\x12\x12\n\x0e\x43\x41\x43HE_DISABLED\x10\x00\x12\x0e\n\nCACHE_MISS\x10\x01\x12\r\n\tCACHE_HIT\x10\x02\x12\x13\n\x0f\x43\x41\x43HE_POPULATED\x10\x03\x12\x18\n\x14\x43\x41\x43HE_LOOKUP_FAILURE\x10\x04\x12\x15\n\x11\x43\x41\x43HE_PUT_FAILURE\x10\x05\x42\x36Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/coreb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,])

_CATALOGCACHESTATUS = _descriptor.EnumDescriptor(
  name='CatalogCacheStatus',
  full_name='flyteidl.core.CatalogCacheStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CACHE_DISABLED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CACHE_MISS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CACHE_HIT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CACHE_POPULATED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CACHE_LOOKUP_FAILURE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CACHE_PUT_FAILURE', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=514,
  serialized_end=655,
)
_sym_db.RegisterEnumDescriptor(_CATALOGCACHESTATUS)

CatalogCacheStatus = enum_type_wrapper.EnumTypeWrapper(_CATALOGCACHESTATUS)
CACHE_DISABLED = 0
CACHE_MISS = 1
CACHE_HIT = 2
CACHE_POPULATED = 3
CACHE_LOOKUP_FAILURE = 4
CACHE_PUT_FAILURE = 5


_CATALOGRESERVATION_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='flyteidl.core.CatalogReservation.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVATION_DISABLED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESERVATION_ACQUIRED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESERVATION_EXISTS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESERVATION_RELEASED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESERVATION_FAILURE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=376,
  serialized_end=511,
)
_sym_db.RegisterEnumDescriptor(_CATALOGRESERVATION_STATUS)


_CATALOGARTIFACTTAG = _descriptor.Descriptor(
  name='CatalogArtifactTag',
  full_name='flyteidl.core.CatalogArtifactTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifact_id', full_name='flyteidl.core.CatalogArtifactTag.artifact_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.core.CatalogArtifactTag.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=133,
)


_CATALOGMETADATA = _descriptor.Descriptor(
  name='CatalogMetadata',
  full_name='flyteidl.core.CatalogMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='flyteidl.core.CatalogMetadata.dataset_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='artifact_tag', full_name='flyteidl.core.CatalogMetadata.artifact_tag', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_task_execution', full_name='flyteidl.core.CatalogMetadata.source_task_execution', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source_execution', full_name='flyteidl.core.CatalogMetadata.source_execution',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=136,
  serialized_end=350,
)


_CATALOGRESERVATION = _descriptor.Descriptor(
  name='CatalogReservation',
  full_name='flyteidl.core.CatalogReservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CATALOGRESERVATION_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=353,
  serialized_end=511,
)

_CATALOGMETADATA.fields_by_name['dataset_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_CATALOGMETADATA.fields_by_name['artifact_tag'].message_type = _CATALOGARTIFACTTAG
_CATALOGMETADATA.fields_by_name['source_task_execution'].message_type = flyteidl_dot_core_dot_identifier__pb2._TASKEXECUTIONIDENTIFIER
_CATALOGMETADATA.oneofs_by_name['source_execution'].fields.append(
  _CATALOGMETADATA.fields_by_name['source_task_execution'])
_CATALOGMETADATA.fields_by_name['source_task_execution'].containing_oneof = _CATALOGMETADATA.oneofs_by_name['source_execution']
_CATALOGRESERVATION_STATUS.containing_type = _CATALOGRESERVATION
DESCRIPTOR.message_types_by_name['CatalogArtifactTag'] = _CATALOGARTIFACTTAG
DESCRIPTOR.message_types_by_name['CatalogMetadata'] = _CATALOGMETADATA
DESCRIPTOR.message_types_by_name['CatalogReservation'] = _CATALOGRESERVATION
DESCRIPTOR.enum_types_by_name['CatalogCacheStatus'] = _CATALOGCACHESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CatalogArtifactTag = _reflection.GeneratedProtocolMessageType('CatalogArtifactTag', (_message.Message,), dict(
  DESCRIPTOR = _CATALOGARTIFACTTAG,
  __module__ = 'flyteidl.core.catalog_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.CatalogArtifactTag)
  ))
_sym_db.RegisterMessage(CatalogArtifactTag)

CatalogMetadata = _reflection.GeneratedProtocolMessageType('CatalogMetadata', (_message.Message,), dict(
  DESCRIPTOR = _CATALOGMETADATA,
  __module__ = 'flyteidl.core.catalog_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.CatalogMetadata)
  ))
_sym_db.RegisterMessage(CatalogMetadata)

CatalogReservation = _reflection.GeneratedProtocolMessageType('CatalogReservation', (_message.Message,), dict(
  DESCRIPTOR = _CATALOGRESERVATION,
  __module__ = 'flyteidl.core.catalog_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.CatalogReservation)
  ))
_sym_db.RegisterMessage(CatalogReservation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/waitable.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import execution_pb2 as flyteidl_dot_core_dot_execution__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/waitable.proto',
  package='flyteidl.plugins',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n\x1f\x66lyteidl/plugins/waitable.proto\x12\x10\x66lyteidl.plugins\x1a\x1d\x66lyteidl/core/execution.proto\x1a\x1e\x66lyteidl/core/identifier.proto\"\x96\x01\n\x08Waitable\x12>\n\nwf_exec_id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\x35\n\x05phase\x18\x02 \x01(\x0e\x32&.flyteidl.core.WorkflowExecution.Phase\x12\x13\n\x0bworkflow_id\x18\x03 \x01(\tB9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_execution__pb2.DESCRIPTOR,flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,])




_WAITABLE = _descriptor.Descriptor(
  name='Waitable',
  full_name='flyteidl.plugins.Waitable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wf_exec_id', full_name='flyteidl.plugins.Waitable.wf_exec_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='flyteidl.plugins.Waitable.phase', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='flyteidl.plugins.Waitable.workflow_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=267,
)

_WAITABLE.fields_by_name['wf_exec_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_WAITABLE.fields_by_name['phase'].enum_type = flyteidl_dot_core_dot_execution__pb2._WORKFLOWEXECUTION_PHASE
DESCRIPTOR.message_types_by_name['Waitable'] = _WAITABLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Waitable = _reflection.GeneratedProtocolMessageType('Waitable', (_message.Message,), dict(
  DESCRIPTOR = _WAITABLE,
  __module__ = 'flyteidl.plugins.waitable_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.Waitable)
  ))
_sym_db.RegisterMessage(Waitable)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/launch_plan.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import execution_pb2 as flyteidl_dot_core_dot_execution__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.core import interface_pb2 as flyteidl_dot_core_dot_interface__pb2
from flyteidl.core import security_pb2 as flyteidl_dot_core_dot_security__pb2
from flyteidl.admin import schedule_pb2 as flyteidl_dot_admin_dot_schedule__pb2
from flyteidl.admin import common_pb2 as flyteidl_dot_admin_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/launch_plan.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n flyteidl/admin/launch_plan.proto\x12\x0e\x66lyteidl.admin\x1a\x1d\x66lyteidl/core/execution.proto\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1d\x66lyteidl/core/interface.proto\x1a\x1c\x66lyteidl/core/security.proto\x1a\x1d\x66lyteidl/admin/schedule.proto\x1a\x1b\x66lyteidl/admin/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"n\n\x17LaunchPlanCreateRequest\x12%\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.flyteidl.admin.LaunchPlanSpec\"\x1a\n\x18LaunchPlanCreateResponse\"\x95\x01\n\nLaunchPlan\x12%\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.flyteidl.admin.LaunchPlanSpec\x12\x32\n\x07\x63losure\x18\x03 \x01(\x0b\x32!.flyteidl.admin.LaunchPlanClosure\"Q\n\x0eLaunchPlanList\x12\x30\n\x0claunch_plans\x18\x01 \x03(\x0b\x32\x1a.flyteidl.admin.LaunchPlan\x12\r\n\x05token\x18\x02 \x01(\t\"J\n\x04\x41uth\x12\x1a\n\x12\x61ssumable_iam_role\x18\x01 \x01(\t\x12\"\n\x1akubernetes_service_account\x18\x02 \x01(\t:\x02\x18\x01\"\xfd\x04\n\x0eLaunchPlanSpec\x12.\n\x0bworkflow_id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12;\n\x0f\x65ntity_metadata\x18\x02 \x01(\x0b\x32\".flyteidl.admin.LaunchPlanMetadata\x12\x33\n\x0e\x64\x65\x66\x61ult_inputs\x18\x03 \x01(\x0b\x32\x1b.flyteidl.core.ParameterMap\x12/\n\x0c\x66ixed_inputs\x18\x04 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\x12\x10\n\x04role\x18\x05 \x01(\tB\x02\x18\x01\x12&\n\x06labels\x18\x06 \x01(\x0b\x32\x16.flyteidl.admin.Labels\x12\x30\n\x0b\x61nnotations\x18\x07 \x01(\x0b\x32\x1b.flyteidl.admin.Annotations\x12&\n\x04\x61uth\x18\x08 \x01(\x0b\x32\x14.flyteidl.admin.AuthB\x02\x18\x01\x12/\n\tauth_role\x18\t \x01(\x0b\x32\x18.flyteidl.admin.AuthRoleB\x02\x18\x01\x12\x38\n\x10security_context\x18\n \x01(\x0b\x32\x1e.flyteidl.core.SecurityContext\x12;\n\x12quality_of_service\x18\x10 \x01(\x0b\x32\x1f.flyteidl.core.QualityOfService\x12\x43\n\x16raw_output_data_config\x18\x11 \x01(\x0b\x32#.flyteidl.admin.RawOutputDataConfig\x12\x17\n\x0fmax_parallelism\x18\x12 \x01(\x05\"\x8f\x02\n\x11LaunchPlanClosure\x12.\n\x05state\x18\x01 \x01(\x0e\x32\x1f.flyteidl.admin.LaunchPlanState\x12\x34\n\x0f\x65xpected_inputs\x18\x02 \x01(\x0b\x32\x1b.flyteidl.core.ParameterMap\x12\x34\n\x10\x65xpected_outputs\x18\x03 \x01(\x0b\x32\x1a.flyteidl.core.VariableMap\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"u\n\x12LaunchPlanMetadata\x12*\n\x08schedule\x18\x01 \x01(\x0b\x32\x18.flyteidl.admin.Schedule\x12\x33\n\rnotifications\x18\x02 \x03(\x0b\x32\x1c.flyteidl.admin.Notification\"p\n\x17LaunchPlanUpdateRequest\x12%\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12.\n\x05state\x18\x02 \x01(\x0e\x32\x1f.flyteidl.admin.LaunchPlanState\"\x1a\n\x18LaunchPlanUpdateResponse\"L\n\x17\x41\x63tiveLaunchPlanRequest\x12\x31\n\x02id\x18\x01 \x01(\x0b\x32%.flyteidl.admin.NamedEntityIdentifier\"\x83\x01\n\x1b\x41\x63tiveLaunchPlanListRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\r\x12\r\n\x05token\x18\x04 \x01(\t\x12%\n\x07sort_by\x18\x05 \x01(\x0b\x32\x14.flyteidl.admin.Sort*+\n\x0fLaunchPlanState\x12\x0c\n\x08INACTIVE\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x42\x37Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_execution__pb2.DESCRIPTOR,flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,flyteidl_dot_core_dot_interface__pb2.DESCRIPTOR,flyteidl_dot_core_dot_security__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_schedule__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_common__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_LAUNCHPLANSTATE = _descriptor.EnumDescriptor(
  name='LaunchPlanState',
  full_name='flyteidl.admin.LaunchPlanState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2137,
  serialized_end=2180,
)
_sym_db.RegisterEnumDescriptor(_LAUNCHPLANSTATE)

LaunchPlanState = enum_type_wrapper.EnumTypeWrapper(_LAUNCHPLANSTATE)
INACTIVE = 0
ACTIVE = 1



_LAUNCHPLANCREATEREQUEST = _descriptor.Descriptor(
  name='LaunchPlanCreateRequest',
  full_name='flyteidl.admin.LaunchPlanCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.LaunchPlanCreateRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='flyteidl.admin.LaunchPlanCreateRequest.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=409,
)


_LAUNCHPLANCREATERESPONSE = _descriptor.Descriptor(
  name='LaunchPlanCreateResponse',
  full_name='flyteidl.admin.LaunchPlanCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=437,
)


_LAUNCHPLAN = _descriptor.Descriptor(
  name='LaunchPlan',
  full_name='flyteidl.admin.LaunchPlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.LaunchPlan.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='flyteidl.admin.LaunchPlan.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closure', full_name='flyteidl.admin.LaunchPlan.closure', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=589,
)


_LAUNCHPLANLIST = _descriptor.Descriptor(
  name='LaunchPlanList',
  full_name='flyteidl.admin.LaunchPlanList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='launch_plans', full_name='flyteidl.admin.LaunchPlanList.launch_plans', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.LaunchPlanList.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=591,
  serialized_end=672,
)


_AUTH = _descriptor.Descriptor(
  name='Auth',
  full_name='flyteidl.admin.Auth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='assumable_iam_role', full_name='flyteidl.admin.Auth.assumable_iam_role', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kubernetes_service_account', full_name='flyteidl.admin.Auth.kubernetes_service_account', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\030\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=748,
)


_LAUNCHPLANSPEC = _descriptor.Descriptor(
  name='LaunchPlanSpec',
  full_name='flyteidl.admin.LaunchPlanSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='flyteidl.admin.LaunchPlanSpec.workflow_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity_metadata', full_name='flyteidl.admin.LaunchPlanSpec.entity_metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_inputs', full_name='flyteidl.admin.LaunchPlanSpec.default_inputs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixed_inputs', full_name='flyteidl.admin.LaunchPlanSpec.fixed_inputs', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='flyteidl.admin.LaunchPlanSpec.role', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='flyteidl.admin.LaunchPlanSpec.labels', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='flyteidl.admin.LaunchPlanSpec.annotations', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth', full_name='flyteidl.admin.LaunchPlanSpec.auth', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_role', full_name='flyteidl.admin.LaunchPlanSpec.auth_role', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='security_context', full_name='flyteidl.admin.LaunchPlanSpec.security_context', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality_of_service', full_name='flyteidl.admin.LaunchPlanSpec.quality_of_service', index=10,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_output_data_config', full_name='flyteidl.admin.LaunchPlanSpec.raw_output_data_config', index=11,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_parallelism', full_name='flyteidl.admin.LaunchPlanSpec.max_parallelism', index=12,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=1388,
)


_LAUNCHPLANCLOSURE = _descriptor.Descriptor(
  name='LaunchPlanClosure',
  full_name='flyteidl.admin.LaunchPlanClosure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='flyteidl.admin.LaunchPlanClosure.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expected_inputs', full_name='flyteidl.admin.LaunchPlanClosure.expected_inputs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expected_outputs', full_name='flyteidl.admin.LaunchPlanClosure.expected_outputs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='flyteidl.admin.LaunchPlanClosure.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='flyteidl.admin.LaunchPlanClosure.updated_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1391,
  serialized_end=1662,
)


_LAUNCHPLANMETADATA = _descriptor.Descriptor(
  name='LaunchPlanMetadata',
  full_name='flyteidl.admin.LaunchPlanMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='flyteidl.admin.LaunchPlanMetadata.schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notifications', full_name='flyteidl.admin.LaunchPlanMetadata.notifications', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1664,
  serialized_end=1781,
)


_LAUNCHPLANUPDATEREQUEST = _descriptor.Descriptor(
  name='LaunchPlanUpdateRequest',
  full_name='flyteidl.admin.LaunchPlanUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.LaunchPlanUpdateRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='flyteidl.admin.LaunchPlanUpdateRequest.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1783,
  serialized_end=1895,
)


_LAUNCHPLANUPDATERESPONSE = _descriptor.Descriptor(
  name='LaunchPlanUpdateResponse',
  full_name='flyteidl.admin.LaunchPlanUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1897,
  serialized_end=1923,
)


_ACTIVELAUNCHPLANREQUEST = _descriptor.Descriptor(
  name='ActiveLaunchPlanRequest',
  full_name='flyteidl.admin.ActiveLaunchPlanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ActiveLaunchPlanRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1925,
  serialized_end=2001,
)


_ACTIVELAUNCHPLANLISTREQUEST = _descriptor.Descriptor(
  name='ActiveLaunchPlanListRequest',
  full_name='flyteidl.admin.ActiveLaunchPlanListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ActiveLaunchPlanListRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.ActiveLaunchPlanListRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='flyteidl.admin.ActiveLaunchPlanListRequest.limit', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.ActiveLaunchPlanListRequest.token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_by', full_name='flyteidl.admin.ActiveLaunchPlanListRequest.sort_by', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2004,
  serialized_end=2135,
)

_LAUNCHPLANCREATEREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_LAUNCHPLANCREATEREQUEST.fields_by_name['spec'].message_type = _LAUNCHPLANSPEC
_LAUNCHPLAN.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_LAUNCHPLAN.fields_by_name['spec'].message_type = _LAUNCHPLANSPEC
_LAUNCHPLAN.fields_by_name['closure'].message_type = _LAUNCHPLANCLOSURE
_LAUNCHPLANLIST.fields_by_name['launch_plans'].message_type = _LAUNCHPLAN
_LAUNCHPLANSPEC.fields_by_name['workflow_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_LAUNCHPLANSPEC.fields_by_name['entity_metadata'].message_type = _LAUNCHPLANMETADATA
_LAUNCHPLANSPEC.fields_by_name['default_inputs'].message_type = flyteidl_dot_core_dot_interface__pb2._PARAMETERMAP
_LAUNCHPLANSPEC.fields_by_name['fixed_inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_LAUNCHPLANSPEC.fields_by_name['labels'].message_type = flyteidl_dot_admin_dot_common__pb2._LABELS
_LAUNCHPLANSPEC.fields_by_name['annotations'].message_type = flyteidl_dot_admin_dot_common__pb2._ANNOTATIONS
_LAUNCHPLANSPEC.fields_by_name['auth'].message_type = _AUTH
_LAUNCHPLANSPEC.fields_by_name['auth_role'].message_type = flyteidl_dot_admin_dot_common__pb2._AUTHROLE
_LAUNCHPLANSPEC.fields_by_name['security_context'].message_type = flyteidl_dot_core_dot_security__pb2._SECURITYCONTEXT
_LAUNCHPLANSPEC.fields_by_name['quality_of_service'].message_type = flyteidl_dot_core_dot_execution__pb2._QUALITYOFSERVICE
_LAUNCHPLANSPEC.fields_by_name['raw_output_data_config'].message_type = flyteidl_dot_admin_dot_common__pb2._RAWOUTPUTDATACONFIG
_LAUNCHPLANCLOSURE.fields_by_name['state'].enum_type = _LAUNCHPLANSTATE
_LAUNCHPLANCLOSURE.fields_by_name['expected_inputs'].message_type = flyteidl_dot_core_dot_interface__pb2._PARAMETERMAP
_LAUNCHPLANCLOSURE.fields_by_name['expected_outputs'].message_type = flyteidl_dot_core_dot_interface__pb2._VARIABLEMAP
_LAUNCHPLANCLOSURE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LAUNCHPLANCLOSURE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LAUNCHPLANMETADATA.fields_by_name['schedule'].message_type = flyteidl_dot_admin_dot_schedule__pb2._SCHEDULE
_LAUNCHPLANMETADATA.fields_by_name['notifications'].message_type = flyteidl_dot_admin_dot_common__pb2._NOTIFICATION
_LAUNCHPLANUPDATEREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_LAUNCHPLANUPDATEREQUEST.fields_by_name['state'].enum_type = _LAUNCHPLANSTATE
_ACTIVELAUNCHPLANREQUEST.fields_by_name['id'].message_type = flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYIDENTIFIER
_ACTIVELAUNCHPLANLISTREQUEST.fields_by_name['sort_by'].message_type = flyteidl_dot_admin_dot_common__pb2._SORT
DESCRIPTOR.message_types_by_name['LaunchPlanCreateRequest'] = _LAUNCHPLANCREATEREQUEST
DESCRIPTOR.message_types_by_name['LaunchPlanCreateResponse'] = _LAUNCHPLANCREATERESPONSE
DESCRIPTOR.message_types_by_name['LaunchPlan'] = _LAUNCHPLAN
DESCRIPTOR.message_types_by_name['LaunchPlanList'] = _LAUNCHPLANLIST
DESCRIPTOR.message_types_by_name['Auth'] = _AUTH
DESCRIPTOR.message_types_by_name['LaunchPlanSpec'] = _LAUNCHPLANSPEC
DESCRIPTOR.message_types_by_name['LaunchPlanClosure'] = _LAUNCHPLANCLOSURE
DESCRIPTOR.message_types_by_name['LaunchPlanMetadata'] = _LAUNCHPLANMETADATA
DESCRIPTOR.message_types_by_name['LaunchPlanUpdateRequest'] = _LAUNCHPLANUPDATEREQUEST
DESCRIPTOR.message_types_by_name['LaunchPlanUpdateResponse'] = _LAUNCHPLANUPDATERESPONSE
DESCRIPTOR.message_types_by_name['ActiveLaunchPlanRequest'] = _ACTIVELAUNCHPLANREQUEST
DESCRIPTOR.message_types_by_name['ActiveLaunchPlanListRequest'] = _ACTIVELAUNCHPLANLISTREQUEST
DESCRIPTOR.enum_types_by_name['LaunchPlanState'] = _LAUNCHPLANSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaunchPlanCreateRequest = _reflection.GeneratedProtocolMessageType('LaunchPlanCreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _LAUNCHPLANCREATEREQUEST,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LaunchPlanCreateRequest)
  ))
_sym_db.RegisterMessage(LaunchPlanCreateRequest)

LaunchPlanCreateResponse = _reflection.GeneratedProtocolMessageType('LaunchPlanCreateResponse', (_message.Message,), dict(
  DESCRIPTOR = _LAUNCHPLANCREATERESPONSE,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LaunchPlanCreateResponse)
  ))
_sym_db.RegisterMessage(LaunchPlanCreateResponse)

LaunchPlan = _reflection.GeneratedProtocolMessageType('LaunchPlan', (_message.Message,), dict(
  DESCRIPTOR = _LAUNCHPLAN,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LaunchPlan)
  ))
_sym_db.RegisterMessage(LaunchPlan)

LaunchPlanList = _reflection.GeneratedProtocolMessageType('LaunchPlanList', (_message.Message,), dict(
  DESCRIPTOR = _LAUNCHPLANLIST,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LaunchPlanList)
  ))
_sym_db.RegisterMessage(LaunchPlanList)

Auth = _reflection.GeneratedProtocolMessageType('Auth', (_message.Message,), dict(
  DESCRIPTOR = _AUTH,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Auth)
  ))
_sym_db.RegisterMessage(Auth)

LaunchPlanSpec = _reflection.GeneratedProtocolMessageType('LaunchPlanSpec', (_message.Message,), dict(
  DESCRIPTOR = _LAUNCHPLANSPEC,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LaunchPlanSpec)
  ))
_sym_db.RegisterMessage(LaunchPlanSpec)

LaunchPlanClosure = _reflection.GeneratedProtocolMessageType('LaunchPlanClosure', (_message.Message,), dict(
  DESCRIPTOR = _LAUNCHPLANCLOSURE,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LaunchPlanClosure)
  ))
_sym_db.RegisterMessage(LaunchPlanClosure)

LaunchPlanMetadata = _reflection.GeneratedProtocolMessageType('LaunchPlanMetadata', (_message.Message,), dict(
  DESCRIPTOR = _LAUNCHPLANMETADATA,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LaunchPlanMetadata)
  ))
_sym_db.RegisterMessage(LaunchPlanMetadata)

LaunchPlanUpdateRequest = _reflection.GeneratedProtocolMessageType('LaunchPlanUpdateRequest', (_message.Message,), dict(
  DESCRIPTOR = _LAUNCHPLANUPDATEREQUEST,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LaunchPlanUpdateRequest)
  ))
_sym_db.RegisterMessage(LaunchPlanUpdateRequest)

LaunchPlanUpdateResponse = _reflection.GeneratedProtocolMessageType('LaunchPlanUpdateResponse', (_message.Message,), dict(
  DESCRIPTOR = _LAUNCHPLANUPDATERESPONSE,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LaunchPlanUpdateResponse)
  ))
_sym_db.RegisterMessage(LaunchPlanUpdateResponse)

ActiveLaunchPlanRequest = _reflection.GeneratedProtocolMessageType('ActiveLaunchPlanRequest', (_message.Message,), dict(
  DESCRIPTOR = _ACTIVELAUNCHPLANREQUEST,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ActiveLaunchPlanRequest)
  ))
_sym_db.RegisterMessage(ActiveLaunchPlanRequest)

ActiveLaunchPlanListRequest = _reflection.GeneratedProtocolMessageType('ActiveLaunchPlanListRequest', (_message.Message,), dict(
  DESCRIPTOR = _ACTIVELAUNCHPLANLISTREQUEST,
  __module__ = 'flyteidl.admin.launch_plan_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ActiveLaunchPlanListRequest)
  ))
_sym_db.RegisterMessage(ActiveLaunchPlanListRequest)


DESCRIPTOR._options = None
_AUTH._options = None
_LAUNCHPLANSPEC.fields_by_name['role']._options = None
_LAUNCHPLANSPEC.fields_by_name['auth']._options = None
_LAUNCHPLANSPEC.fields_by_name['auth_role']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/version.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/version.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\x1c\x66lyteidl/admin/version.proto\x12\x0e\x66lyteidl.admin\"L\n\x12GetVersionResponse\x12\x36\n\x15\x63ontrol_plane_version\x18\x01 \x01(\x0b\x32\x17.flyteidl.admin.Version\"<\n\x07Version\x12\r\n\x05\x42uild\x18\x01 \x01(\t\x12\x0f\n\x07Version\x18\x02 \x01(\t\x12\x11\n\tBuildTime\x18\x03 \x01(\t\"\x13\n\x11GetVersionRequestB7Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
)




_GETVERSIONRESPONSE = _descriptor.Descriptor(
  name='GetVersionResponse',
  full_name='flyteidl.admin.GetVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='control_plane_version', full_name='flyteidl.admin.GetVersionResponse.control_plane_version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=124,
)


_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='flyteidl.admin.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Build', full_name='flyteidl.admin.Version.Build', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Version', full_name='flyteidl.admin.Version.Version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='BuildTime', full_name='flyteidl.admin.Version.BuildTime', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=186,
)


_GETVERSIONREQUEST = _descriptor.Descriptor(
  name='GetVersionRequest',
  full_name='flyteidl.admin.GetVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=207,
)

_GETVERSIONRESPONSE.fields_by_name['control_plane_version'].message_type = _VERSION
DESCRIPTOR.message_types_by_name['GetVersionResponse'] = _GETVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['Version'] = _VERSION
DESCRIPTOR.message_types_by_name['GetVersionRequest'] = _GETVERSIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetVersionResponse = _reflection.GeneratedProtocolMessageType('GetVersionResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVERSIONRESPONSE,
  __module__ = 'flyteidl.admin.version_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.GetVersionResponse)
  ))
_sym_db.RegisterMessage(GetVersionResponse)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), dict(
  DESCRIPTOR = _VERSION,
  __module__ = 'flyteidl.admin.version_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Version)
  ))
_sym_db.RegisterMessage(Version)

GetVersionRequest = _reflection.GeneratedProtocolMessageType('GetVersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETVERSIONREQUEST,
  __module__ = 'flyteidl.admin.version_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.GetVersionRequest)
  ))
_sym_db.RegisterMessage(GetVersionRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/project_domain_attributes.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.admin import matchable_resource_pb2 as flyteidl_dot_admin_dot_matchable__resource__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/project_domain_attributes.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n.flyteidl/admin/project_domain_attributes.proto\x12\x0e\x66lyteidl.admin\x1a\'flyteidl/admin/matchable_resource.proto\"{\n\x17ProjectDomainAttributes\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12?\n\x13matching_attributes\x18\x03 \x01(\x0b\x32\".flyteidl.admin.MatchingAttributes\"c\n$ProjectDomainAttributesUpdateRequest\x12;\n\nattributes\x18\x01 \x01(\x0b\x32\'.flyteidl.admin.ProjectDomainAttributes\"\'\n%ProjectDomainAttributesUpdateResponse\"~\n!ProjectDomainAttributesGetRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x38\n\rresource_type\x18\x03 \x01(\x0e\x32!.flyteidl.admin.MatchableResource\"a\n\"ProjectDomainAttributesGetResponse\x12;\n\nattributes\x18\x01 \x01(\x0b\x32\'.flyteidl.admin.ProjectDomainAttributes\"\x81\x01\n$ProjectDomainAttributesDeleteRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x38\n\rresource_type\x18\x03 \x01(\x0e\x32!.flyteidl.admin.MatchableResource\"\'\n%ProjectDomainAttributesDeleteResponseB7Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_admin_dot_matchable__resource__pb2.DESCRIPTOR,])




_PROJECTDOMAINATTRIBUTES = _descriptor.Descriptor(
  name='ProjectDomainAttributes',
  full_name='flyteidl.admin.ProjectDomainAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ProjectDomainAttributes.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.ProjectDomainAttributes.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matching_attributes', full_name='flyteidl.admin.ProjectDomainAttributes.matching_attributes', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=230,
)


_PROJECTDOMAINATTRIBUTESUPDATEREQUEST = _descriptor.Descriptor(
  name='ProjectDomainAttributesUpdateRequest',
  full_name='flyteidl.admin.ProjectDomainAttributesUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='flyteidl.admin.ProjectDomainAttributesUpdateRequest.attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=331,
)


_PROJECTDOMAINATTRIBUTESUPDATERESPONSE = _descriptor.Descriptor(
  name='ProjectDomainAttributesUpdateResponse',
  full_name='flyteidl.admin.ProjectDomainAttributesUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=372,
)


_PROJECTDOMAINATTRIBUTESGETREQUEST = _descriptor.Descriptor(
  name='ProjectDomainAttributesGetRequest',
  full_name='flyteidl.admin.ProjectDomainAttributesGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ProjectDomainAttributesGetRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.ProjectDomainAttributesGetRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.ProjectDomainAttributesGetRequest.resource_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=374,
  serialized_end=500,
)


_PROJECTDOMAINATTRIBUTESGETRESPONSE = _descriptor.Descriptor(
  name='ProjectDomainAttributesGetResponse',
  full_name='flyteidl.admin.ProjectDomainAttributesGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='flyteidl.admin.ProjectDomainAttributesGetResponse.attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=599,
)


_PROJECTDOMAINATTRIBUTESDELETEREQUEST = _descriptor.Descriptor(
  name='ProjectDomainAttributesDeleteRequest',
  full_name='flyteidl.admin.ProjectDomainAttributesDeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ProjectDomainAttributesDeleteRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.ProjectDomainAttributesDeleteRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.ProjectDomainAttributesDeleteRequest.resource_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=731,
)


_PROJECTDOMAINATTRIBUTESDELETERESPONSE = _descriptor.Descriptor(
  name='ProjectDomainAttributesDeleteResponse',
  full_name='flyteidl.admin.ProjectDomainAttributesDeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=772,
)

_PROJECTDOMAINATTRIBUTES.fields_by_name['matching_attributes'].message_type = flyteidl_dot_admin_dot_matchable__resource__pb2._MATCHINGATTRIBUTES
_PROJECTDOMAINATTRIBUTESUPDATEREQUEST.fields_by_name['attributes'].message_type = _PROJECTDOMAINATTRIBUTES
_PROJECTDOMAINATTRIBUTESGETREQUEST.fields_by_name['resource_type'].enum_type = flyteidl_dot_admin_dot_matchable__resource__pb2._MATCHABLERESOURCE
_PROJECTDOMAINATTRIBUTESGETRESPONSE.fields_by_name['attributes'].message_type = _PROJECTDOMAINATTRIBUTES
_PROJECTDOMAINATTRIBUTESDELETEREQUEST.fields_by_name['resource_type'].enum_type = flyteidl_dot_admin_dot_matchable__resource__pb2._MATCHABLERESOURCE
DESCRIPTOR.message_types_by_name['ProjectDomainAttributes'] = _PROJECTDOMAINATTRIBUTES
DESCRIPTOR.message_types_by_name['ProjectDomainAttributesUpdateRequest'] = _PROJECTDOMAINATTRIBUTESUPDATEREQUEST
DESCRIPTOR.message_types_by_name['ProjectDomainAttributesUpdateResponse'] = _PROJECTDOMAINATTRIBUTESUPDATERESPONSE
DESCRIPTOR.message_types_by_name['ProjectDomainAttributesGetRequest'] = _PROJECTDOMAINATTRIBUTESGETREQUEST
DESCRIPTOR.message_types_by_name['ProjectDomainAttributesGetResponse'] = _PROJECTDOMAINATTRIBUTESGETRESPONSE
DESCRIPTOR.message_types_by_name['ProjectDomainAttributesDeleteRequest'] = _PROJECTDOMAINATTRIBUTESDELETEREQUEST
DESCRIPTOR.message_types_by_name['ProjectDomainAttributesDeleteResponse'] = _PROJECTDOMAINATTRIBUTESDELETERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProjectDomainAttributes = _reflection.GeneratedProtocolMessageType('ProjectDomainAttributes', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTDOMAINATTRIBUTES,
  __module__ = 'flyteidl.admin.project_domain_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectDomainAttributes)
  ))
_sym_db.RegisterMessage(ProjectDomainAttributes)

ProjectDomainAttributesUpdateRequest = _reflection.GeneratedProtocolMessageType('ProjectDomainAttributesUpdateRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTDOMAINATTRIBUTESUPDATEREQUEST,
  __module__ = 'flyteidl.admin.project_domain_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectDomainAttributesUpdateRequest)
  ))
_sym_db.RegisterMessage(ProjectDomainAttributesUpdateRequest)

ProjectDomainAttributesUpdateResponse = _reflection.GeneratedProtocolMessageType('ProjectDomainAttributesUpdateResponse', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTDOMAINATTRIBUTESUPDATERESPONSE,
  __module__ = 'flyteidl.admin.project_domain_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectDomainAttributesUpdateResponse)
  ))
_sym_db.RegisterMessage(ProjectDomainAttributesUpdateResponse)

ProjectDomainAttributesGetRequest = _reflection.GeneratedProtocolMessageType('ProjectDomainAttributesGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTDOMAINATTRIBUTESGETREQUEST,
  __module__ = 'flyteidl.admin.project_domain_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectDomainAttributesGetRequest)
  ))
_sym_db.RegisterMessage(ProjectDomainAttributesGetRequest)

ProjectDomainAttributesGetResponse = _reflection.GeneratedProtocolMessageType('ProjectDomainAttributesGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTDOMAINATTRIBUTESGETRESPONSE,
  __module__ = 'flyteidl.admin.project_domain_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectDomainAttributesGetResponse)
  ))
_sym_db.RegisterMessage(ProjectDomainAttributesGetResponse)

ProjectDomainAttributesDeleteRequest = _reflection.GeneratedProtocolMessageType('ProjectDomainAttributesDeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTDOMAINATTRIBUTESDELETEREQUEST,
  __module__ = 'flyteidl.admin.project_domain_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectDomainAttributesDeleteRequest)
  ))
_sym_db.RegisterMessage(ProjectDomainAttributesDeleteRequest)

ProjectDomainAttributesDeleteResponse = _reflection.GeneratedProtocolMessageType('ProjectDomainAttributesDeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTDOMAINATTRIBUTESDELETERESPONSE,
  __module__ = 'flyteidl.admin.project_domain_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectDomainAttributesDeleteResponse)
  ))
_sym_db.RegisterMessage(ProjectDomainAttributesDeleteResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
